def accdivdif(x):
    r"""
    Compute divided differences of the exponential function at the points x.

    INPUT:

    - ``x`` -- points. x[0].prec() is used to set the precision. If x[0]
      has not such an attribute, precision = 53.

    OUTPUT:

    - ``d`` -- list of divided differences.
    """
    if (hasattr(x[0], 'prec')):
        precision = x[0].prec()
    else:
        precision = 53
    m = len(x)-1
    mu = sum(x) / (m+1)
    x = [x[i]-mu for i in [0..m]]
    s = max(ceil(max([abs(x[i]) for i in [0..m]]) / 0.7),1)
    ## check wheter x contains complex numbers
    FFF = RealField(prec = precision)
    i = 0
    while (i < m+1):
        if (x[i].imag() != 0):
            FFF = ComplexField(prec = precision) # work in complex arithmetic
            break
        i += 1
    F = matrix(FFF,m+1,lambda i,j:1/s^abs(i-j)/factorial(abs(i-j)))
    load("getl.sage")
    lmax = getl(precision)
    for l in [1..lmax]:
        for j in [0..m-1]:
            F[j,j] *= x[j] / l / s
            for i in [j+1..m]:
                F[i,j] = (x[i] * F[i,j] + F[i-1,j]) / (l+i-j) / s
                F[j,i] += F[i,j]
    for j in [0..m]:
        F[j,j] = exp(x[j]/s)
        F[j+1:m+1,j] = 0 # upper triangular part
    d = exp(mu)*F.row(0)
    for i in [1..s-1]:
        d *=  F
    return list(d)
