def bea(a,tol,precision):
    r"""
    Perform the backward error analysis of `a[0]+a[1]*x+...+a[m]*x^m`.

    INPUT:

    - ``a`` -- list of coefficients of the polynomial. a[0] must be 1.

    - ``tol`` -- the machine precision.

    - ``precision`` -- the number of bits to use in the analysis.

    OUTPUT:

    ``theta`` -- the value theta.

    EXAMPLES:

    Backward error analysis of Taylor's series.

    ::

        sage: load("lejaptslist.sage")
        sage: load("intpol.sage")
        sage: load("leja.sage")
        sage: load("bea.sage")
        sage: bea(intpol(leja(31,30,0,lejapts),165),2^(-53),165)
        3.539666348743689268183409326947152468028961964128

    Bacward error analysis of Leja's interpolant.

    ::

        sage: load("lejaptslist.sage")
        sage: load("intpol.sage")
        sage: load("leja.sage")
        sage: load("bea.sage")
        sage: bea(intpol(leja(31,0,1.5,lejapts),165),2^(-53),165)
        3.574127342441199225786914887208852354409331852594

    Bacward error analysis of complex Leja's interpolant.

    ::

        sage: load("lejasymptslist.sage")
        sage: load("intpol.sage")
        sage: load("leja.sage")
        sage: load("bea.sage")
        sage: bea(intpol(leja(31,0,I*1.5,lejasympts),165),2^(-53),165)
        3.395697794156717179926638912131164179620510169266
    """
    var('x')
    m = len(a)-1
    ## check wheter a contains complex numbers
    FFF = RealField(prec = precision)
    i = 0
    while ((i < m+1) and (a[i].imag() == 0)):
        i += 1
    if (i < m+1):
        FFF = ComplexField(prec = precision) # work in complex arithmetic
    a = [FFF(a[i]) for i in [0..m]]
    M = m*3
    coef01 = [0] * (M+1)
    coef01[:m+1] = a
    # we need exp(-A)P_m(A)
    # we define R_m(A) = exp(A)-P_m(A)
    # exp(-A)P_m(A) = I-exp(-A)*R_m(A)
    # log(exp(-A)P_m(A)) = log(I-exp(-A)*R_m(A)) =
    # = -exp(-A)*R_m(A) + (exp(-A)*R_m(A))^2/2 + ...
    # therefore we need the coefficients of exp(-A)*R_m(A)
    # -R_m(A) = P_m(A)-exp(A) # prone to canc. err.
    coef01 = [coef01[i]-FFF(1)/factorial(i) for i in [0..M]]
    # Coefficients of exp(-A)
    coef02 = [(-FFF(1))^i/factorial(i) for i in [0..M]]
    # Coefficients of exp(-A)*(-R_m(A))
    load("seriesp.sage")
#    coef = convolution(coef02,coef01)[:M+1]
    coef = seriesp(coef02,coef01)
    # Coefficients of: log(I-exp(-A)R_m(A))
    coef01 = coef # accumulate powers
    coef02 = coef
    # compute the number of leading zeros
    ell = next((i for i, x in enumerate(coef) if x != 0),1)-1
    # some leading zeros could be in fact different from zero because of
    # rounding errors, but it does not affect the precision of the code.
    # In particular, if the first coefficient is not exactly zero, we set
    # it to zero
    if (ell == -1):
        coef[0] = 0 # coef01[0] and coef02[0] are set to zero, as well
        ell = 0
    for i in [2..floor(M/(ell+1))]:
        # i is the power in the Taylor expansion of log
#        coef01 = convolution(coef,coef01)[:M+1] # next power
        coef01 = seriesp(coef,coef01) # next power
        coef02 = [coef02[j]+(-1)^(i-1)*coef01[j]/i for j in [0..M]]
    htildeoverx = abs(coef02[M])
    htildeoverx = x*htildeoverx+abs(coef02[M-1])
    itsderivative = 0*x+(M-1)*abs(coef02[M]) # to grant to be a function of x
#    itsderivative(x) = (M-1)*abs(coef02[M]) # to grant to be a function of x
    for i in [M-2..1,step=-1]: # Horner
        htildeoverx = x*htildeoverx+abs(coef02[i])
        itsderivative = x*itsderivative+i*abs(coef02[i+1])
    f = htildeoverx-tol
    RRR = RealField(prec = precision) # now we work in real arithmetic
    x1 = RRR(max(9/10*(24074/100000*m-341309/100000),0)) # left b. to zero
    x2 = RRR(max(11/10*(24074/100000*m-341309/100000),1/100))
    if (f(x=0) > 0):
        print "% WARNING: not possible to find a positive zero "+\
            "of \\tilde h(\\theta)/\\theta."
        theta = 0
        return theta
    f1 = itsderivative
    load("newton.sage")
    theta = newton(f,f1,x1,x2,tol)
    return theta
