def getl(prec):
    r"""
    Return the integer l such that `(0.7)^(l+1)/(l+1)!+(0.7)^(l+2)/(l+2)!`
    is less than `2^(-prec)`.

    INPUT:

    - ``prec`` -- a positive integer

    OUTPUT:

    - ``l``

    REFERENCES:

    - [MCNP84] (2.3.1)

    TESTS:

    sage: getl(165)
    37
    """
    def f(l):
        return (7/10)^(l+1)/factorial(l+1)*(1+(7/10)/(l+2))-2^(-prec)
    l0 = 16 # corresponds to prec=-56, double precision
    f0 = f(l0)
    if (f0 < 0):
        return l0
    l1 = 17
    f1 = f(l1)
    while (f1 > 0):
        l1 *= 2
        f1 = f(l1)
    while (l1-l0 > 1):
        if (f(ceil((l0+l1)/2)) > 0):
            l0 = ceil((l0+l1)/2)
        else:
            l1 = ceil((l0+l1)/2)
    return l1
