def intpol(x,precision):
    r"""
    Return the coefficients a of the polynomial
    `a[0]+a[1]*x+...+a[m]*x^m` which interpolates `exp` at ``x``.

    INPUT:

    - ``x`` -- list of interpolation points.

    - ``precision`` -- the number of bits to use.

    OUTPUT:

    -- ``a`` the coefficients.

    EXAMPLES:

    Coefficients of Taylor's series.

    ::

        sage: load("lejaptslist.sage")
        sage: load("intpol.sage")
        sage: load("leja.sage")
        sage: intpol(leja(31,30,0,lejapts),165)
    """
    # Given the Newton representation
    #
    # y = d(0)+d(1)*(x-xi(0))+...+d(m)*(x-xi(0))*...*(x-xi(m-1))
    #
    # it computes the vector a such that
    #
    # y = a(0)+a(1)*x+...+a(m)*x^(m-1). Stetekluh.
    m = len(x)-1
    ## check wheter x contains complex numbers
    FFF = RealField(prec = precision)
    i = 0
    while (i < m+1):
        if (x[i].imag() != 0):
            FFF = ComplexField(prec = precision) # work in complex arithmetic
            break
        i += 1
    x = [FFF(x[i]) for i in [0..m]]
    load("accdivdif.sage")
    d = accdivdif(x);
    for j in [0..m]:
        for i in [m-1..j,step=-1]:
            d[i] -= x[i-j] * d[i+1]
    return d
