def leja(n,ell,c,lejapoints):
    r"""
    Generate ``n`` Leja--Hermite points with `ell+1` leading zeros in the
    interval `[-c,c]`.

    INPUT:

    - ``n`` -- number of points (= degree + 1)

    - ``ell`` -- number of repetitions of inital zeros

    - ``c`` -- right boundary of the interval `[-c,c]`. Can be purely
      imaginary.

    - ``lejapoints`` -- double list of Leja points. A double list contains
      in position [ell][i] the (i+1)-th point of the sequence with `ell+1`
      zeros. Available lists are:

     lejapts (load("lejaptslist.sage"))

     lejasympts (load("lejasymptslist.sage"))

    OUTPUT:

    - ``x`` -- list of Leja--Hermite points.

    EXAMPLES:

    `10` Leja points in `[-1,1]` with a single leading zero.

    ::

        sage: load("lejaptslist.sage")
        sage: load("leja.sage")
        sage: leja(10,0,1,lejapts)

    `10` Leja points in `[-1,1]` with two leading zeros.

    ::

        sage: load("lejaptslist.sage")
        sage: load("leja.sage")
        sage: leja(10,1,1,lejapts)

    `10` symmetric Leja points in `I*[-1,1]` with two leading zeros.

    ::

        sage: load("lejasymptslist.sage")
        sage: load("leja.sage")
        sage: leja(10,1,I,lejasympts)
    """
    # Keep the first point real, otherwise it is not possible to extract
    # its precision.
    x = [lejapoints[ell][0]] + [c * lejapoints[ell][i]/2 for i in [1..n-1]]
    if (imag(c) !=0 and sum(x) != 0):
        print "leja.sage: complex points not conjugate pairs"
    return x
